.. title:: Sciris

.. image:: docs/sciris-logo.png
    :scale: 40%
    :align: center

`Sciris <http://sciris.org>`__ is library of functions for scientific computing that provide additional flexibility and ease-of-use on top of Numpy, Scipy, and Matplotlib.

ScirisWeb, built on Sciris, is a toolbox that makes building webapps easy -- think of it as `Shiny <https://shiny.rstudio.com/>`__ for Python.

========
Contents
========

.. toctree::
   :maxdepth: 4

   overview
   whatsnew
   code_of_conduct

.. autosummary::
   :toctree: _autosummary
   :caption: API reference
   :template: custom-module-template.rst
   :recursive:

   sciris
